@@ -28,44 +28,43 @@
 
 (define status 0)
 (define curpos 0)
-(define is-playing 0)
+(define playing? 0)
 
 (define open-next-file-in-directory
   (let ((last-file-opened #f)
 	(current-directory #f)
-	(current-sorted-files #f))
-    
-    (define (file-from-path curfile)
-      (let ((last-slash 0))
-	(do ((i 0 (+ 1 i)))
-	    ((= i (length curfile)))
-	  (if (char=? (curfile i) #\/)
-	      (set! last-slash i)))
-	(substring curfile (+ 1 last-slash))))
-    
-    (define (directory-from-path curfile)
-      (let ((last-slash 0))
-	(do ((i 0 (+ 1 i)))
-	    ((= i (length curfile)))
-	  (if (char=? (curfile i) #\/)
-	      (set! last-slash i)))
-	(substring curfile 0 last-slash)))
-    
-    (define (find-next-file)
-      ;; find the next file in the sorted list, with wrap-around
-      (let ((choose-next (not (string? last-file-opened)))
-	    (just-filename (file-from-path last-file-opened)))
-	(call-with-exit
-	 (lambda (return)
-	   (for-each
-	    (lambda (file)
-	      (if choose-next
-		  (return file)
-		  (if (string=? file just-filename)
-		      (set! choose-next #t))))
-	    current-sorted-files)
-	   ;; if we get here we wrapped around
-	   (car current-sorted-files)))))
+	(current-sorted-files #f)
+	(directory-from-path (lambda (curfile)
+			       (do ((last-slash 0)
+				    (i 0 (+ 1 i)))
+				   ((= i (length curfile))
+				    (substring curfile 0 last-slash))   
+				 (if (char=? (curfile i) #\/)
+				     (set! last-slash i))))))
+
+    (define find-next-file
+      (let ((file-from-path (lambda (curfile)
+			      (do ((last-slash 0)
+				   (i 0 (+ 1 i)))
+				  ((= i (length curfile))
+				   (substring curfile (+ 1 last-slash)))   
+				(if (char=? (curfile i) #\/)
+				    (set! last-slash i))))))
+	(lambda ()
+	  ;; find the next file in the sorted list, with wrap-around
+	  (let ((choose-next (not (string? last-file-opened)))
+		(just-filename (file-from-path last-file-opened)))
+	    (call-with-exit
+	     (lambda (return)
+	       (for-each
+		(lambda (file)
+		  (if choose-next
+		      (return file)
+		      (if (string=? file just-filename)
+			  (set! choose-next #t))))
+		current-sorted-files)
+	       ;; if we get here we wrapped around
+	       (car current-sorted-files)))))))
     
     (define (get-current-files dir)
       (set! current-directory dir)
@@ -120,12 +119,12 @@
 
 (hook-push start-playing-hook 
 	   (lambda (hook)
-	     (set! is-playing 1)))
+	     (set! playing? 1)))
 
 
 (hook-push stop-playing-hook 
 	   (lambda (hook)
-	     (set! is-playing 0)))
+	     (set! playing? 0)))
 
 (define (eos )
   (set! (cursor) (+ (selection-position) (selection-framples))))
@@ -300,7 +299,7 @@
   )
 
 (define (toggle-play)
-  (lambda () (case is-playing
+  (lambda () (case playing?
 	       ((1) (stop-playing))
 	       ((0) (play))
 	       )))
