@@ -11,15 +11,6 @@
 
 (unless (defined? '*notcurses*)          ; nrepl.c has notcurses_s7.c (thus *notcurses*) built-in
   (load "notcurses_s7.so" (inlet 'init_func 'notcurses_s7_init)))
-(unless (defined? 'nccell_make)        (define nccell_make cell_make))
-(unless (defined? 'nccell_gcluster)    (define nccell_gcluster cell_gcluster))
-(unless (defined? 'nccell_channels)    (define nccell_channels cell_channels))
-(unless (defined? 'nccell_stylemask)   (define nccell_stylemask cell_stylemask))
-(unless (defined? 'nccells_double_box) (define nccells_double_box cells_double_box))
-
-(unless (defined? 'CELL_FGDEFAULT_MASK) (define CELL_FGDEFAULT_MASK NC_FGDEFAULT_MASK))
-(unless (defined? 'CELL_BGDEFAULT_MASK) (define CELL_BGDEFAULT_MASK NC_BGDEFAULT_MASK))
-
 (unless (defined? 'notcurses_getc) (define (notcurses_getc a b c d) (notcurses_get a b d)))
 
 (define (drop-into-repl call e)
@@ -151,7 +142,7 @@
 					       result))))))
 			     (make-iterator iterloop))))))
 
-		(lambda* (name (e (*nrepl* 'top-level-let)))
+		(lambda* (name (e (sublet (*nrepl* 'top-level-let) *notcurses*)))
 		  (let ((ap-name (if (string? name) name
 				     (if (symbol? name)
 					 (symbol->string name)
@@ -267,7 +258,7 @@
 			       (ash (floor (* g 256)) 8)
 			       (floor (* b 256)))))
 	    (set! (nccell_gcluster c1) (char->integer #\space))
-	    (set! (nccell_channels c1) (logior CELL_FGDEFAULT_MASK CELL_BGDEFAULT_MASK color)))
+	    (set! (nccell_channels c1) (logior (ash NC_BGDEFAULT_MASK 32) NC_BGDEFAULT_MASK color)))
 	  (set! (nccell_stylemask c1) 0)
 	  (ncplane_set_base_cell statp c1)
 	  (notcurses_render nc)
@@ -294,7 +285,7 @@
       (define (red c)
 	(let ((c1 (nccell_make)))
 	  (set! (nccell_gcluster c1) (char->integer c))
-	  (set! (nccell_channels c1)  (logior CELL_FGDEFAULT_MASK #xff000000000000))
+	  (set! (nccell_channels c1)  (logior (ash NC_BGDEFAULT_MASK 32) #xff000000000000))
 	  (set! (nccell_stylemask c1) 0)
 	  c1))
 
@@ -405,6 +396,12 @@
 	      (set! (nccell_channels c1) 0)
 	      (set! (nccell_stylemask c1) 0)
 	      (ncplane_set_base_cell ncp c1)
+
+	      (unless header
+		(set! header-row 1) ; avoid first row -- output is meesed up by notcurses
+		(set! row 1)
+		(set! header-cols nc-cols))
+
 	      (notcurses_render nc))
 
 	    (let ((last-name ""))
@@ -605,16 +602,17 @@
 	    ;; we load lint above, at which time it sets its *output-port* to *stderr* (the global built-in port), but
 	    ;;   when called in the repl, we have over-ridden *stderr* to place that output in the notcurses display,
 	    ;;   so we need to redirect lint's output by hand.
-	    (set! lint ; force top-level change
-	      (let ((old-lint lint))
-		(lambda* (file (outp :unset) (report-input :unset))
-		  (if (and (eq? outp :unset)
-			   (eq? report-input :unset))
-		      (nc-multiline-display
-		       (call-with-output-string
-			(lambda (p)
-			  (old-lint file p))))
-		      (old-lint file outp report-input)))))
+	    (when with-lint
+	      (set! lint ; force top-level change
+		    (let ((old-lint lint))
+		      (lambda* (file (outp :unset) (report-input :unset))
+			(if (and (eq? outp :unset)
+				 (eq? report-input :unset))
+			    (nc-multiline-display
+			     (call-with-output-string
+			      (lambda (p)
+				(old-lint file p))))
+			    (old-lint file outp report-input))))))
 
 
 	    ;; -------- top-level-let --------
@@ -1094,11 +1092,11 @@
 								      (when (eq? (h 'plane) ncp)
 									(set! ncp-row (h 'y))
 									(set! ncp-col (h 'x)))))))
-					     (set-sigint-handler)                                  ; catch C-C to interrupt computation
+					     ;(set-sigint-handler)                                 ; catch C-C to interrupt computation -- this no longer works in notcurses
 					     (let ((str (with-output-to-string                     ; for scheme side output
 							  (lambda ()
 							    (set! val (list (new-eval form envir))))))) ; list, not lambda -- confuses trace!
-					       (unset-sigint-handler nc)                           ; catch C-C to exit cleanly
+					       ;(unset-sigint-handler nc)                           ; catch C-C to exit cleanly
 
 					       (for-each
 						(lambda (s)
@@ -1123,7 +1121,7 @@
 					   (nc-multiline-display (object->string val))))))
 
 				   (lambda (type info)
-				     (unset-sigint-handler nc)
+				     ;(unset-sigint-handler nc)
 				     (if (eq? type 'string-read-error)
 					 (begin
 					   ;; missing close paren, newline already added, spaces here are not optional!
@@ -1133,7 +1131,7 @@
 					 (apply throw type info)))))   ; re-raise error
 
 			       (lambda (type info)
-				 (unset-sigint-handler nc)
+				 ;(unset-sigint-handler nc)
 				 (if (and (eq? type 'read-error)       ; maybe we hit <enter> in a block comment
 					  (equal? info '("unexpected end of input while reading #|")))
 				     (begin
@@ -1184,11 +1182,10 @@
 			  (if (char-separator? (ncplane_contents ncp row col 1 1))
 			      (loop (- col 1))
 			      (let loop ((col col))
-				(if (= col (bols row))
+				(if (or (= col (bols row))
+					(char-separator? (ncplane_contents ncp row (- col 1) 1 1)))
 				    col
-				    (if (char-separator? (ncplane_contents ncp row (- col 1) 1 1))
-					col
-					(loop (- col 1)))))))))
+				    (loop (- col 1))))))))
                   (define (word-forward-x)
                     (let loop ((col (min (eols row) (+ col 1))))
                       (if (= col (eols row))
@@ -1196,11 +1193,10 @@
 			  (if (char-separator? (ncplane_contents ncp row col 1 1))
 			      (loop (+ col 1))
 			      (let loop ((col col))
-				(if (= col (eols row))
+				(if (or (= col (eols row))
+					(char-separator? (ncplane_contents ncp row col 1 1)))
 				    col
-				    (if (char-separator? (ncplane_contents ncp row col 1 1))
-					col
-					(loop (+ col 1)))))))))
+				    (loop (+ col 1))))))))
 		  
                   (set! (keymap (+ meta-key (char->integer #\B)))
 			(set! (keymap (+ meta-key (char->integer #\b)))
@@ -1302,6 +1298,10 @@
 				    (set-col (eols row))))
 			      (set-col (max (bols row) (- col 1))))))
 
+		  (set! (keymap (+ control-key (char->integer #\C)))
+			(lambda (c)
+			  (set! repl-done #t)))
+
 		  (set! (keymap (+ control-key (char->integer #\D)))
 			(lambda (c)
 			  (when (and (< col (eols row)) ; should this delete the newline?
@@ -1496,18 +1496,18 @@
 			(lambda (c)
 			  ;; ncinput gives row|col in current view, so we need to map that to the ncplane row|col
 			  ;(display-status (format #f "nc-rows: ~S, ncp-row: ~S, input: ~S" nc-rows ncp-row (ncinput_y ni)))
-			  (set-row (min ncp-max-row (- (ncinput_y ni) ncp-row)))
-			  (set-col (max (min (eols row) (ncinput_x ni)) (bols row)))
-			  (unless mouse-col
-			    (set! mouse-col col)
-			    (set! mouse-row row))))
-
-		  (set! (keymap NCKEY_RELEASE)  ; mouse button release
-			(lambda (c)
-			  (when (and (number? mouse-col)
-				     (not (= col mouse-col)))
-			    (set! selection (ncplane_contents ncp mouse-row (min col mouse-col) 1 (abs (- col mouse-col)))))
-			  (set! mouse-col #f)))
+			  (if (= (ncinput_evtype ni) NCTYPE_RELEASE)
+			      (begin
+				(when (and (number? mouse-col)
+					   (not (= col mouse-col)))
+				  (set! selection (ncplane_contents ncp mouse-row (min col mouse-col) 1 (abs (- col mouse-col)))))
+				(set! mouse-col #f))
+			      (begin
+				(set-row (min ncp-max-row (- (ncinput_y ni) ncp-row)))
+				(set-col (max (min (eols row) (ncinput_x ni)) (bols row)))
+				(unless mouse-col
+				  (set! mouse-col col)
+				  (set! mouse-row row))))))
 
 		  (set! (keymap NCKEY_ENTER) enter)
 
@@ -1712,7 +1712,7 @@
 		(set! nc (notcurses_core_init noptions)))
 	      (notcurses_cursor_enable nc 0 2)
 	      (unless (string-position "rxvt" ((libc-let 'getenv) "TERM"))
-		(notcurses_mouse_enable nc)) ; 0 if ok, -1 if failure
+		(notcurses_mice_enable nc NCMICE_ALL_EVENTS)) ; 0 if ok, -1 if failure
 	      (let ((size (ncplane_dim_yx (notcurses_stdplane nc))))
 		(set! nc-cols (cadr size))
 		(set! nc-rows (car size))
@@ -1727,9 +1727,7 @@
 
   (with-let *nrepl*
     (start)
-    (if (string=? (notcurses_version) "2.3.17")
-	(run ">" "version 2.3.17 needs this header!") ; surely this is a bug! 2.3.13 seems to be ok
-	(run))
+    (run)
     (stop)))
 
 ;; selection (both ways):
