@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "15-Mar-24"
+#define SND_DATE "21-Apr-24"
 #ifndef SND_VERSION
-#define SND_VERSION "25.2"
+#define SND_VERSION "25.3"
 #endif
 #define SND_MAJOR_VERSION "25"
-#define SND_MINOR_VERSION "2"
+#define SND_MINOR_VERSION "3"
 
 #endif
