@@ -233,6 +233,8 @@
 ;   (format #t "~A~%" n))
 ; (sort! calls (lambda (a b) (< (car a) (car b)))))
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (#_exit)
 
 
