@@ -526,13 +526,10 @@
 (t)
 
 #|
-(format *stderr* "copy~%")
 (test-copy 1000000)
-;100000 : .1
-;1000000 : 4.6
-;10000000 : 356 = about 120 million objects = about 6Gbytes, mark_pair/gc 
-;(format *stderr* "append~%")
-;(test-append 10000)
+;100000 : .089
+;1000000 : 1.7
+;10000000 : 121
 |#
 
 (when (> (*s7* 'profile) 0)
